@@ -15,8 +15,7 @@ if (typeof WScript !== "undefined") {
 require('child-process-close')
 
 var EventEmitter = require("events").EventEmitter
-  , npm = module.exports = new EventEmitter
-  , config = require("./config.js")
+  , npm = module.exports = new EventEmitter()
   , npmconf = require("npmconf")
   , log = require("npmlog")
   , fs = require("graceful-fs")
@@ -275,6 +274,8 @@ npm.load = function (cli, cb_) {
 
   function cb (er) {
     if (loadErr) return
+    loadErr = er
+    if (er) return cb_(er)
     if (npm.config.get("force")) {
       log.warn("using --force", "I sure hope you know what you are doing.")
     }
@@ -307,6 +308,9 @@ function load (npm, cli, cb) {
     npmconf.load(cli, builtin, function (er, config) {
       if (er === config) er = null
 
+      npm.config = config
+      if (er) return cb(er)
+
       // Include npm-version and node-version in user-agent
       var ua = config.get("user-agent") || ""
       ua = ua.replace(/\{node-version\}/gi, process.version)
@@ -315,8 +319,6 @@ function load (npm, cli, cb) {
       ua = ua.replace(/\{arch\}/gi, process.arch)
       config.set("user-agent", ua)
 
-      npm.config = config
-
       var color = config.get("color")
 
       log.level = config.get("loglevel")
