@@ -70,8 +70,7 @@ function outdated (args, silent, cb) {
 
 // [[ dir, dep, has, want, latest ]]
 function makePretty (p) {
-  var parseable = npm.config.get("parseable")
-    , dep = p[1]
+  var dep = p[1]
     , dir = path.resolve(p[0], "node_modules", dep)
     , has = p[2]
     , want = p[3]
@@ -268,17 +267,14 @@ function shouldUpdate (args, dir, dep, has, req, depth, cb) {
   if (isGitUrl(url.parse(req)))
     return doIt("git", "git")
 
-  var registry = npm.registry
   // search for the latest package
-  registry.get(dep, function (er, d) {
+  var uri = url.resolve(npm.config.get("registry"), dep)
+  npm.registry.get(uri, null, function (er, d) {
     if (er) return cb()
     if (!d || !d['dist-tags'] || !d.versions) return cb()
     var l = d.versions[d['dist-tags'].latest]
     if (!l) return cb()
 
-    // set to true if found in doc
-    var found = false
-
     var r = req
     if (d['dist-tags'][req])
       r = d['dist-tags'][req]
