@@ -1,7 +1,8 @@
 
 module.exports = star
 
-var npm = require("./npm.js")
+var url = require("url")
+  , npm = require("./npm.js")
   , registry = npm.registry
   , log = require("npmlog")
   , asyncMap = require("slide").asyncMap
@@ -10,7 +11,8 @@ star.usage = "npm star <package> [pkg, pkg, ...]\n"
            + "npm unstar <package> [pkg, pkg, ...]"
 
 star.completion = function (opts, cb) {
-  registry.get("/-/short", 60000, function (er, list) {
+  var uri = url.resolve(npm.config.get("registry"), "/-/short")
+  registry.get(uri, { timeout : 60000 }, function (er, list) {
     return cb(null, list || [])
   })
 }
@@ -22,7 +24,8 @@ function star (args, cb) {
     , using = !(npm.command.match(/^un/))
   if (!using) s = u
   asyncMap(args, function (pkg, cb) {
-    registry.star(pkg, using, function (er, data, raw, req) {
+    var uri = url.resolve(npm.config.get("registry"), pkg)
+    registry.star(uri, using, function (er, data, raw, req) {
       if (!er) {
         console.log(s + " "+pkg)
         log.verbose("star", data)
