@@ -13,7 +13,7 @@ var cbCalled = false
 
 process.on("exit", function (code) {
   // console.error("exit", code)
-  if (!npm.config.loaded) return
+  if (!npm.config || !npm.config.loaded) return
   if (code) itWorked = false
   if (itWorked) log.info("ok")
   else {
@@ -46,7 +46,7 @@ process.on("exit", function (code) {
 function exit (code, noLog) {
   exitCode = exitCode || process.exitCode || code
 
-  var doExit = npm.config.get("_exit")
+  var doExit = npm.config ? npm.config.get("_exit") : true
   log.verbose("exit", [code, doExit])
   if (log.level === "silent") noLog = true
 
@@ -71,7 +71,7 @@ function exit (code, noLog) {
 function errorHandler (er) {
   var printStack = false
   // console.error("errorHandler", er)
-  if (!npm.config.loaded) {
+  if (!npm.config || !npm.config.loaded) {
     // logging won't work unless we pretend that it's ready
     er = er || new Error("Exit prior to config file resolving.")
     console.error(er.stack || er.message)
